@@ -16,7 +16,7 @@ normalizeFilename <- function(x, form = c("default", "8.3")[1], fix.encoding = T
    # shorten the path:
    if(form == "8.3"){
       if(.Platform$OS.type == "windows") {
-       x <- shortPathName(x)
+       x <- utils::shortPathName(x)
       }
    }
    if(fix.encoding==TRUE){
